@@ -25,13 +25,26 @@ SMALL_SIZE = 7
 MEDIUM_SIZE = 9
 BIGGER_SIZE = 12
 
-plt.rc('font', size=MEDIUM_SIZE)          # controls default text sizes
-plt.rc('axes', titlesize=MEDIUM_SIZE)     # fontsize of the axes title
-plt.rc('axes', labelsize=MEDIUM_SIZE)    # fontsize of the x and y labels
-plt.rc('xtick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
-plt.rc('ytick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
-plt.rc('legend', fontsize=SMALL_SIZE)    # legend fontsize
-plt.rc('figure', titlesize=MEDIUM_SIZE)  # fontsize of the figure title
+def set_powerpoint_sizes():
+	
+	plt.rc('font', size=BIGGER_SIZE)          # controls default text sizes
+	plt.rc('axes', titlesize=BIGGER_SIZE)     # fontsize of the axes title
+	plt.rc('axes', labelsize=BIGGER_SIZE)    # fontsize of the x and y labels
+	plt.rc('xtick', labelsize=BIGGER_SIZE)    # fontsize of the tick labels
+	plt.rc('ytick', labelsize=BIGGER_SIZE)    # fontsize of the tick labels
+	plt.rc('legend', fontsize=BIGGER_SIZE)    # legend fontsize
+	plt.rc('figure', titlesize=BIGGER_SIZE)  # fontsize of the figure title
+	
+def set_article_sizes():
+	
+	plt.rc('font', size=MEDIUM_SIZE)          # controls default text sizes
+	plt.rc('axes', titlesize=MEDIUM_SIZE)     # fontsize of the axes title
+	plt.rc('axes', labelsize=MEDIUM_SIZE)    # fontsize of the x and y labels
+	plt.rc('xtick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
+	plt.rc('ytick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
+	plt.rc('legend', fontsize=SMALL_SIZE)    # legend fontsize
+	plt.rc('figure', titlesize=MEDIUM_SIZE)  # fontsize of the figure title
+
 
 def string_to_dict(string, item_delimiter=',', pair_delimiter=None):
 	if pair_delimiter is not None:
@@ -40,18 +53,72 @@ def string_to_dict(string, item_delimiter=',', pair_delimiter=None):
 		string_dict = {item.split()[0]:item.split()[1] for item in string.split(item_delimiter) if len(item.split()) > 1}
 		
 	return string_dict
+	
+def query_enhancer_atlas(path_enhancer_file):
+	
+	"""
+	
+	Queries an enhancer atlas txt file and returns a dictionary of coordinates. Can additionally pass a list of gene/transcript names/ids to filter.
+	Return format: {gene_name: [[chromosome, start, stop], [chromosome, start, stop] ... ] ... }
 
-def query_gtf_coordinates(path_gtf, sequence_type, identifier, gene_name_filter_list = None):
+	:param path_enhancer_file:	Path of the enhancer atlas text file
+	
+	Example:
+	
+	>>> return_dict = query_enhancer_atlas('/home/data/Shared/genome_reference_files/hg19/regions/hg19_H1_EnhancerGenePair_EnhancerAtlas2.0.txt')
+	
+	"""
+	
+	enhancer_df_ga = pd.read_csv(path_enhancer_file, sep='\t', names = ['data', 'wtf'])
+	enhancer_ga_records = enhancer_df_ga.to_records()
+	enhancer_gene_pairs = [enhancer['data'].replace(':','\t').replace('-','\t').replace('_','\t').replace('$','\t').split('\t') for enhancer in enhancer_ga_records]
+	enhancer_ga_records = [{'chrom': enhancer_gene_pair[0], 'start': int(enhancer_gene_pair[1]), 'stop': int(enhancer_gene_pair[2]), 'genecard_id': enhancer_gene_pair[4]} for enhancer_gene_pair in enhancer_gene_pairs]
+	
+	enhancer_coord_dict = {}
+	
+	for enhancer in enhancer_ga_records:
+	
+		if enhancer['genecard_id'] not in enhancer_coord_dict:
+			enhancer_coord_dict[enhancer['genecard_id']] = []
+		
+		enhancer_coord_dict[enhancer['genecard_id']].append([enhancer['chrom'], start, stop])
+		
+	return enhancer_coord_dict
+
+
+def query_gtf_coordinates(path_gtf, sequence_type, key, gene_name_filter_list = None):
+	
+	"""
+	
+	Queries a gtf file and returns a dictionary of coordinates. Can additionally pass a list of gene/transcript names/ids to filter.
+	Return format: {key: [chromosome, gene_start, gene_stop, strand] ... }
+
+	:param path_gtf:		Path to a gtf file
+
+	:param sequence_type:	Which relevant genomic type is to be retrieved from the gtf file. 
+							Possible values: transcript, exon, 5UTR, CDS, start_codon, stop_codon, 3UTR
+	
+	:param key: 			Which information to use as the key for the return dictionary.
+							Possible values: gene_id, transcript_id, exon_number, exon_id, gene_name
+							
+	:param gene_name_filter_list:		Optional, function returns a truncated dictionary containing information for matching keys.
+	
+	
+	Example:
+	
+	>>> query_gtf_coordinates('/home/data/Shared/genome_reference_files/hg19/hg19.refGene.gtf', 'transcript', 'gene_name', gene_name_filter_list = ['GAPDH'])
+	
+	"""
 	
 	#'/home/data/Shared/genome_reference_files/hg19/hg19.refGene.gtf'
-	# sequence_type='transcript', identifier='gene_name'
+	# sequence_type='transcript', key='gene_name'
 	
 	gtf_df = pd.read_csv(path_gtf, sep='\t', names=['chromosome', 'gene_id_source', 'sequence_type', 'start', 'stop', 'null1', 'strand', 'null2', 'id_data'])
 	
 	gtf_df_transcripts = gtf_df.loc[gtf_df['sequence_type'] == sequence_type]
 	gtf_df_transcripts_records = gtf_df_transcripts.to_records()
 	
-	gene_coordinate_dict = {string_to_dict(record['id_data'], item_delimiter=';', pair_delimiter=None)[identifier].replace('"', ''): [str(record['chromosome']), int(record['start']), int(record['stop']), str(record['strand'])] for record in gtf_df_transcripts_records if identifier in string_to_dict(record['id_data'], item_delimiter=';', pair_delimiter=None)}
+	gene_coordinate_dict = {string_to_dict(record['id_data'], item_delimiter=';', pair_delimiter=None)[key].replace('"', ''): [str(record['chromosome']), int(record['start']), int(record['stop']), str(record['strand'])] for record in gtf_df_transcripts_records if key in string_to_dict(record['id_data'], item_delimiter=';', pair_delimiter=None)}
 	
 	if gene_name_filter_list is not None:
 	
@@ -152,7 +219,7 @@ def savefile_with_readme(args, stack, path_file, data_file_string):
 	
 	with open(path_readme, 'w') as file:
 		file.write(text_readme)
-
+		
 def savefig_with_readme(args, stack, path_fig):
 	
 	plt.savefig(path_fig)
@@ -290,7 +357,13 @@ def set_size(w,h, ax=None):
 	figh = float(h)/(t-b)
 	ax.figure.set_size_inches(figw, figh)
 
-def plot_kde(df, x_name, filename, path_plot_dir, xlim=None, title=None, **kwargs):
+def plot_kde(df, x_name, filename, path_plot_dir, font_sizes=None, xlim=None, title=None, **kwargs):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	fig, ax = plt.subplots()
 	
@@ -306,7 +379,13 @@ def plot_kde(df, x_name, filename, path_plot_dir, xlim=None, title=None, **kwarg
 	savefig_with_readme(str(sys.argv), inspect.stack(), path_png)
 	plt.close()	
 
-def plot_2d_kde(x, y, filename, path_plot_dir, ylim=None, xlim=None, xlabel=None, ylabel=None, title=None, **kwargs):
+def plot_2d_kde(x, y, filename, path_plot_dir, font_sizes=None, ylim=None, xlim=None, xlabel=None, ylabel=None, title=None, **kwargs):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	fig, ax = plt.subplots()
 	
@@ -330,10 +409,20 @@ def plot_2d_kde(x, y, filename, path_plot_dir, ylim=None, xlim=None, xlabel=None
 	plt.show()
 	path_png = os.path.join(path_plot_dir, filename + '.png')
 	savefig_with_readme(str(sys.argv), inspect.stack(), path_png)
+	
+	path_svg = os.path.join(path_plot_dir, filename + '.svg')
+	savefig_with_readme(str(sys.argv), inspect.stack(), path_svg)
+	
 	plt.close()
 
 
-def plot_scatter_list(x, y, filename, path_plot_dir, ylim=None, xlim=None, xlabel=None, ylabel=None, title=None, **kwargs):
+def plot_scatter_list(x, y, filename, path_plot_dir, font_sizes=None, ylim=None, xlim=None, xlabel=None, ylabel=None, title=None, **kwargs):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	fig, ax = plt.subplots()
 	
@@ -359,7 +448,13 @@ def plot_scatter_list(x, y, filename, path_plot_dir, ylim=None, xlim=None, xlabe
 	savefig_with_readme(str(sys.argv), inspect.stack(), path_png)
 	plt.close()
 	
-def plot_hist(df, x_name, filename, path_plot_dir, ylim=None, xlim=None, title=None, **kwargs):
+def plot_hist(df, x_name, filename, path_plot_dir, font_sizes=None, ylim=None, xlim=None, title=None, **kwargs):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	fig, ax = plt.subplots()
 	
@@ -378,7 +473,13 @@ def plot_hist(df, x_name, filename, path_plot_dir, ylim=None, xlim=None, title=N
 	savefig_with_readme(str(sys.argv), inspect.stack(), path_png)
 	plt.close()	
 
-def plot_hist_list(data_list, filename, path_plot_dir, ylim=None, xlim=None, title=None, **kwargs):
+def plot_hist_list(data_list, filename, path_plot_dir, font_sizes=None, ylim=None, xlim=None, title=None, **kwargs):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	fig, ax = plt.subplots()
 	
@@ -397,7 +498,13 @@ def plot_hist_list(data_list, filename, path_plot_dir, ylim=None, xlim=None, tit
 	savefig_with_readme(str(sys.argv), inspect.stack(), path_png)
 	plt.close()
 	
-def plot_violin(df, x, y, order, filename, path_plot_dir, fig_width=None, fig_height=None, palette_name=None, metric=None, stat_test=None, rotate_x=False, xlabel=None, ylabel=None, ylim=None, hue=None, hue_order=None, pad_top=False, pad_bottom=False, pad_left=False, pad_right=False, title=None, **kwargs):
+def plot_violin(df, x, y, order, filename, path_plot_dir, font_sizes=None, fig_width=None, fig_height=None, palette_name=None, metric=None, stat_test=None, rotate_x=False, xlabel=None, ylabel=None, ylim=None, hue=None, hue_order=None, pad_top=False, pad_bottom=False, pad_left=False, pad_right=False, title=None, **kwargs):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	if pad_top and pad_bottom:
 		fig, ax = plt.subplots(figsize = (8, 10))
@@ -466,7 +573,13 @@ def plot_violin(df, x, y, order, filename, path_plot_dir, fig_width=None, fig_he
 	savefig_with_readme(str(sys.argv), inspect.stack(), path_png)
 	plt.close()	
 	
-def plot_box(df, x, y, order, filename, path_plot_dir, fig_width=None, fig_height=None, palette_name=None, add_n=False, add_stat=False, rotate_x=False, xlabel=None, ylabel=None, ylim=None, hue=None, hue_order=None, pad_top=False, pad_bottom=False, pad_left=False, pad_right=False, title=None, **kwargs):
+def plot_box(df, x, y, order, filename, path_plot_dir, font_sizes=None, fig_width=None, fig_height=None, palette_name=None, add_n=False, add_stat=False, rotate_x=False, xlabel=None, ylabel=None, ylim=None, hue=None, hue_order=None, pad_top=False, pad_bottom=False, pad_left=False, pad_right=False, title=None, **kwargs):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	fig, ax = plt.subplots()
 	if pad_top:
@@ -529,7 +642,13 @@ def plot_box(df, x, y, order, filename, path_plot_dir, fig_width=None, fig_heigh
 def scale_num(new_max, new_min, old_max, old_min, val):
 	return (new_max - new_min) * (val - old_min) / (old_max - old_min) + new_min
 	
-def plot_line(df, x_name, y_name, filename, path_plot_dir, hue=None, custom_ci_names=None, ylim=None, title=None, fig_width=None, fig_height=None, xticks=None, **kwargs):
+def plot_line(df, x_name, y_name, filename, path_plot_dir, font_sizes=None, hue=None, custom_ci_names=None, ylim=None, title=None, fig_width=None, fig_height=None, xticks=None, **kwargs):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	fig, ax = plt.subplots()
 	
@@ -538,6 +657,7 @@ def plot_line(df, x_name, y_name, filename, path_plot_dir, hue=None, custom_ci_n
 		hue_order = list(set(df[hue].tolist()))
 		hue_order.sort(key=natural_keys)
 		palette=sns.color_palette("mako", n_colors=len(hue_order))
+		palette.reverse()
 		
 		# ci = 1.96 * np.std(y)/np.sqrt(len(x))
 	
@@ -589,7 +709,13 @@ def plot_line(df, x_name, y_name, filename, path_plot_dir, hue=None, custom_ci_n
 		
 	plt.close()
 	
-def plot_bar(df, x, y, order, filename, path_plot_dir, fig_width=None, fig_height=None, add_n=False, add_stat=False, rotate_x=False, xlabel=None, ylabel=None, ylim=None, hue=None, hue_order=None, **kwargs):
+def plot_bar(df, x, y, order, filename, path_plot_dir, font_sizes = None, fig_width=None, fig_height=None, add_n=False, add_stat=False, rotate_x=False, xlabel=None, ylabel=None, ylim=None, hue=None, hue_order=None, **kwargs):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	fig, ax = plt.subplots()
 	fig.subplots_adjust(left=0.25, right=0.85, top=0.55, bottom=0.25)
@@ -687,7 +813,13 @@ def add_stdev(df, x, y, order, ax, colors=None):
 			plt.plot(pos[tick], means[tick], marker='D', markersize=3)
 
 
-def plot_mean_and_sem(df, x, y, order, filename, path_plot_dir, fig_width=None, fig_height=None, colors=None, rotate_x=False, xlabel=None, ylabel=None, ylim=None):
+def plot_mean_and_sem(df, x, y, order, filename, path_plot_dir, font_sizes=None, fig_width=None, fig_height=None, colors=None, rotate_x=False, xlabel=None, ylabel=None, ylim=None):
+	
+	if font_sizes is not None:
+		if font_sizes == 'powerpoint':
+			set_powerpoint_sizes()
+		elif font_sizes == 'article':
+			set_article_sizes()
 	
 	fig, ax = plt.subplots()
 	fig.subplots_adjust(left=0.25, right=0.85, top=0.55, bottom=0.25)
